<?php
class Directive_K2_Helper {
	private $params;
	
	public function __construct($params) {
		$this->params = $params;
	}
	
	public function getK2Categories($parentid = 0) {
		$db = & JFactory::getDBO ();
		
		$query = ' SELECT id,name, alias, parent, ordering FROM #__k2_categories ';
		/* WHERE CONDITION */
		$query .= ' WHERE parent = ' . ( int ) $parentid;
		// Exclude categories
		$catid = $this->params
			->get ( 'exclude_categories' );
		if ($catid) {
			JArrayHelper::toInteger ( $catid );
			$query .= ' AND (id <> ' . implode ( ' OR id <> ', $catid ) . ')';
		}
		$query .= ' AND published = 1 AND trash = 0 '; // Categories must be published and not in trash
		/* ORDERING */
		
		$ordering = $this->params
			->get ( 'cat_ordering' );
		switch ($ordering) {
			case 'c_idasc' :
				$query .= ' ORDER BY id ASC';
				break;
			case 'c_iddesc' :
				$query .= ' ORDER BY id DESC';
				break;
			case 'c_nameasc' :
				$query .= ' ORDER BY name ASC';
				break;
			case 'c_namedesc' :
				$query .= ' ORDER BY name DESC';
				break;
			case 'c_orderasc' :
				$query .= ' ORDER BY ordering ASC';
				break;
			case 'c_orderdesc' :
				$query .= ' ORDER BY ordering DESC';
				break;
			default :
				$query .= ' ORDER BY ordering';
		}
		
		$db->setQuery ( $query );
		
		$list = $db->loadObjectList ();
		
		return $list;
	}
	
	public function getK2Items($catid) {
		$exclude_catid = $this->params
			->get ( 'exclude_item_categories' );
		if (is_array ( $exclude_catid )) {
			if (in_array ( $catid, $exclude_catid )) {
				return false;
			}
		} else {
			if ($exclude_catid == $catid) {
				return false;
			}
		}
		// Get a database object
		$db = & JFactory::getDBO ();
		
		$query = "SELECT i.*, c.name AS categoryname,c.id AS categoryid, c.alias AS categoryalias, c.params AS categoryparams";
		$query .= " FROM #__k2_items as i LEFT JOIN #__k2_categories c ON c.id = i.catid";
		$query .= " WHERE i.published = 1 AND i.trash = 0 AND c.published = 1 AND c.trash = 0 AND c.id = " . ( int ) $catid;
		
		$ordering = $this->params
			->get ( 'item_ordering' );
		switch ($ordering) {
			case 'i_idasc' :
				$query .= ' ORDER BY i.id ASC';
				break;
			case 'i_iddesc' :
				$query .= ' ORDER BY i.id DESC';
				break;
			case 'i_nameasc' :
				$query .= ' ORDER BY i.name ASC';
				break;
			case 'i_namedesc' :
				$query .= ' ORDER BY i.name DESC';
				break;
			case 'i_orderasc' :
				$query .= ' ORDER BY i.ordering ASC';
				break;
			case 'i_orderdesc' :
				$query .= ' ORDER BY i.ordering DESC';
				break;
			default :
				$query .= ' ORDER BY i.ordering';
		}
		
		$db->setQuery ( $query );
		
		return $db->loadObjectList ();
	}
	
	public function renderCategories($parentCategories, $level, $limit) {
		$html = '';
		
		if ($parentCategories) {
			foreach ( $parentCategories as $category ) {
				
				$className = ' level-' . $level . ' parent-' . $category->parent; // ClassName: level-n parent-id
				

				$subCategories = $this->getK2Categories ( $category->id ); // Get sub categories				
				$items = $this->getK2Items ( $category->id ); // Get items 
				

				if ($subCategories || $items) { // Check if have child ( sub cats or items )
					$className .= ' hasChild'; // Category have sub Categories					
				} else {
					$className .= ' noChild'; // Category have no sub Categories
				}
				
				// Cat link
				$href = urldecode ( JRoute::_ ( K2HelperRoute::getCategoryRoute ( $category->id . ':' . urlencode ( $category->alias ) ) ) );
				$ajaxCategory = $this->params->get('ajaxcategory',false);
				$ajaxItem = $this->params->get('ajaxitem',false);
				$container = $this->params->get('container');
				$showcounter = $this->params->get('show_counter',0);
				
				// Render
				$html .= '<div class="k2_category' . $className . '" id="' . $category->id . '" >'; // Wrap cat
					$html .= '<div class="k2_category title" onclick="expandCategory(' . $category->id . ',' . $level . ');return false;" >'; // Moved onClick from a to div cat
						$html .= '<h2><a href="' . $href . '" >';
							$html .= '<span onclick="categoryClick(' . $category->id . ','.$ajaxCategory.',\''.$container.'\')">';
								$html .= $category->name;
								if ( $showcounter == 1 ) {
									$html .= ' ( ' . count($items) . ' ) ';
								} 
							$html .= '</span>';
						$html .= '</a></h2>';
					$html .= '</div>';
				
				// subCategories render
				if ($subCategories) {
					$html .= '<div class="k2_category sub_categories level-' . ( int ) ($level + 1) . '">'; // wrap sub categories
					if ($level < $limit) {
						$html .= $this->renderCategories ( $subCategories, $level + 1, $limit );
					}
					$html .= '</div>'; // end wrap
				}
				
				// Items render
				if ($items) {
					$html .= '<div class="k2_items level-' . ( int ) ($level + 1) . '">'; // wrap items
					foreach ( $items as $item ) {
						$itemhref = urldecode ( JRoute::_ ( K2HelperRoute::getItemRoute ( $item->id, $item->catid . ':' . urlencode ( $item->categoryalias ) ) ) );
						$html .= '<div class="k2_item" id="item-' . $item->id . '">';
						$html .= '<h2><a href="' . $itemhref . '" onclick="expandItem(' . $item->id . ','.$ajaxItem.',\''.$container.'\');return false;" >' . $item->title . '</a></h2>';
						$html .= '</div>';
					}
					$html .= '</div>'; // end wrap items
				}
				$html .= '</div>';
			}
		}
		return $html;
	}
}
?>